@@ -31,9 +31,8 @@ def compute_fast_metrics(
         # pylint: disable=bare-except
         query_embeddings, _ = next(embedding_reader(start=0, end=query_max, batch_size=query_max))
     else:
-        query_embeddings = embedding_reader
+        query_embeddings = embedding_reader[:query_max]
 
-    query_embeddings = query_embeddings[:query_max]
     if omp_threads:
         faiss.omp_set_num_threads(1)
     speeds_ms = search_speed_test(index, query_embeddings, ksearch=40, timout_s=10.0)
